@@ -122,9 +122,9 @@ void RegisteredDocsModel::setDocEntries(const RegisteredDocEntries &e)
 static RegisteredDocEntries registeredDocEntries(const HelpEngineWrapper &wrapper)
 {
     RegisteredDocEntries result;
-    const QStringList nameSpaces = wrapper.registeredDocumentations();
+    const QStringList &nameSpaces = wrapper.registeredDocumentations();
     result.reserve(nameSpaces.size());
-    foreach (const QString &nameSpace, nameSpaces) {
+    for (const QString &nameSpace : nameSpaces) {
         RegisteredDocEntry entry;
         entry.nameSpace = nameSpace;
         entry.fileName = wrapper.documentationFileName(nameSpace);
@@ -152,26 +152,24 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
     connect(m_ui.registeredDocsFilterLineEdit, &QLineEdit::textChanged,
             m_registereredDocsFilterModel, &QSortFilterProxyModel::setFilterFixedString);
 
-    connect(m_ui.buttonBox->button(QDialogButtonBox::Ok), SIGNAL(clicked()),
-        this, SLOT(applyChanges()));
-    connect(m_ui.buttonBox->button(QDialogButtonBox::Cancel), SIGNAL(clicked()),
-        this, SLOT(reject()));
+    connect(m_ui.buttonBox->button(QDialogButtonBox::Ok), &QAbstractButton::clicked,
+            this, &PreferencesDialog::applyChanges);
+    connect(m_ui.buttonBox->button(QDialogButtonBox::Cancel), &QAbstractButton::clicked,
+            this, &QDialog::reject);
 
     if (!m_hideFiltersTab) {
         m_ui.attributeWidget->header()->hide();
         m_ui.attributeWidget->setRootIsDecorated(false);
 
-        connect(m_ui.attributeWidget, SIGNAL(itemChanged(QTreeWidgetItem*,int)),
-            this, SLOT(updateFilterMap()));
+        connect(m_ui.attributeWidget, &QTreeWidget::itemChanged,
+                this, &PreferencesDialog::updateFilterMap);
+        connect(m_ui.filterWidget, &QListWidget::currentItemChanged,
+                this, &PreferencesDialog::updateAttributes);
 
-        connect(m_ui.filterWidget,
-            SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)), this,
-            SLOT(updateAttributes(QListWidgetItem*)));
-
-        connect(m_ui.filterAddButton, SIGNAL(clicked()), this,
-            SLOT(addFilter()));
-        connect(m_ui.filterRemoveButton, SIGNAL(clicked()), this,
-            SLOT(removeFilter()));
+        connect(m_ui.filterAddButton, &QAbstractButton::clicked,
+                this, &PreferencesDialog::addFilter);
+        connect(m_ui.filterRemoveButton, &QAbstractButton::clicked,
+                this, &PreferencesDialog::removeFilter);
 
         updateFilterPage();
     } else {
@@ -179,13 +177,13 @@ PreferencesDialog::PreferencesDialog(QWidget *parent)
     }
 
     if (!m_hideDocsTab) {
-        connect(m_ui.docAddButton, SIGNAL(clicked()), this,
-            SLOT(addDocumentationLocal()));
-        connect(m_ui.docRemoveButton, SIGNAL(clicked()), this,
-            SLOT(removeDocumentation()));
+        connect(m_ui.docAddButton, &QAbstractButton::clicked,
+                this, &PreferencesDialog::addDocumentationLocal);
+        connect(m_ui.docRemoveButton, &QAbstractButton::clicked,
+                this, &PreferencesDialog::removeDocumentation);
 
         m_docsBackup.reserve(m_registeredDocsModel->rowCount());
-        foreach (const RegisteredDocEntry &e, m_registeredDocsModel->docEntries())
+        for (const RegisteredDocEntry &e : m_registeredDocsModel->docEntries())
             m_docsBackup.append(e.nameSpace);
     } else {
         m_ui.tabWidget->removeTab(m_ui.tabWidget->indexOf(m_ui.docsTab));
@@ -239,7 +237,7 @@ void PreferencesDialog::updateFilterPage()
 
     m_filterMapBackup.clear();
     const QStringList &filters = helpEngine.customFilters();
-    foreach (const QString &filter, filters) {
+    for (const QString &filter : filters) {
         if (filter == HelpEngineWrapper::TrUnfiltered())
             continue;
         QStringList atts = helpEngine.filterAttributes(filter);
@@ -250,22 +248,20 @@ void PreferencesDialog::updateFilterPage()
 
     m_ui.filterWidget->addItems(m_filterMap.keys());
 
-    foreach (const QString &a, helpEngine.filterAttributes())
+    for (const QString &a : helpEngine.filterAttributes())
         new QTreeWidgetItem(m_ui.attributeWidget, QStringList() << a);
 
-    if (!m_filterMap.keys().isEmpty())
+    if (!m_filterMap.isEmpty())
         m_ui.filterWidget->setCurrentRow(0);
 }
 
 void PreferencesDialog::updateAttributes(QListWidgetItem *item)
 {
     TRACE_OBJ
-    QStringList checkedList;
-    if (item)
-        checkedList = m_filterMap.value(item->text());
-    QTreeWidgetItem *itm;
+    const QStringList &checkedList = item ? m_filterMap.value(item->text()) : QStringList();
+
     for (int i = 0; i < m_ui.attributeWidget->topLevelItemCount(); ++i) {
-        itm = m_ui.attributeWidget->topLevelItem(i);
+        QTreeWidgetItem *itm = m_ui.attributeWidget->topLevelItem(i);
         if (checkedList.contains(itm->text(0)))
             itm->setCheckState(0, Qt::Checked);
         else
@@ -328,14 +324,14 @@ void PreferencesDialog::removeFilter()
 void PreferencesDialog::addDocumentationLocal()
 {
     TRACE_OBJ
-    const QStringList fileNames = QFileDialog::getOpenFileNames(this,
+    const QStringList &fileNames = QFileDialog::getOpenFileNames(this,
         tr("Add Documentation"), QString(), tr("Qt Compressed Help Files (*.qch)"));
     if (fileNames.isEmpty())
         return;
 
     QStringList invalidFiles;
     QStringList alreadyRegistered;
-    foreach (const QString &fileName, fileNames) {
+    for (const QString &fileName : fileNames) {
         const QString nameSpace = QHelpEngineCore::namespaceName(fileName);
         if (nameSpace.isEmpty()) {
             invalidFiles.append(fileName);
@@ -360,7 +356,7 @@ void PreferencesDialog::addDocumentationLocal()
     if (!invalidFiles.isEmpty() || !alreadyRegistered.isEmpty()) {
         QString message;
         if (!alreadyRegistered.isEmpty()) {
-            foreach (const QString &ns, alreadyRegistered) {
+            for (const QString &ns : qAsConst(alreadyRegistered)) {
                 message += tr("The namespace %1 is already registered!")
                     .arg(QString("<b>%1</b>").arg(ns)) + QLatin1String("<br>");
             }
@@ -371,7 +367,7 @@ void PreferencesDialog::addDocumentationLocal()
         if (!invalidFiles.isEmpty()) {
             message += tr("The specified file is not a valid Qt Help File!");
             message.append(QLatin1String("<ul>"));
-            foreach (const QString &file, invalidFiles)
+            for (const QString &file : qAsConst(invalidFiles))
                 message += QLatin1String("<li>") + file + QLatin1String("</li>");
             message.append(QLatin1String("</ul>"));
         }
@@ -384,7 +380,7 @@ void PreferencesDialog::addDocumentationLocal()
 QList<int> PreferencesDialog::currentRegisteredDocsSelection() const
 {
     QList<int> result;
-    foreach (const QModelIndex &index, m_ui.registeredDocsListView->selectionModel()->selectedRows())
+    for (const QModelIndex &index : m_ui.registeredDocsListView->selectionModel()->selectedRows())
         result.append(m_registereredDocsFilterModel->mapToSource(index).row());
     return result;
 }
@@ -402,7 +398,7 @@ void PreferencesDialog::removeDocumentation()
     bool foundBefore = false;
     for (int i = currentSelection.size() - 1; i >= 0; --i) {
         const int row = currentSelection.at(i);
-        const QString& ns = entries.at(row).nameSpace;
+        const QString &ns = entries.at(row).nameSpace;
         if (!foundBefore && OpenPagesManager::instance()->pagesOpenForNamespace(ns)) {
             if (0 == QMessageBox::information(this, tr("Remove Documentation"),
                 tr("Some documents currently opened in Assistant reference the "
@@ -419,7 +415,7 @@ void PreferencesDialog::removeDocumentation()
     m_registeredDocsModel->setDocEntries(entries);
 
     if (m_registereredDocsFilterModel->rowCount()) {
-        const QModelIndex first = m_registereredDocsFilterModel->index(0, 0);
+        const QModelIndex &first = m_registereredDocsFilterModel->index(0, 0);
         m_ui.registeredDocsListView->selectionModel()->setCurrentIndex(first,
                                                                        QItemSelectionModel::ClearAndSelect);
     }
@@ -433,24 +429,20 @@ void PreferencesDialog::applyChanges()
         if (m_filterMap.count() != m_filterMapBackup.count()) {
             filtersWereChanged = true;
         } else {
-            QMapIterator<QString, QStringList> it(m_filterMapBackup);
-            while (it.hasNext() && !filtersWereChanged) {
-                it.next();
+            for (auto it = m_filterMapBackup.cbegin(), end = m_filterMapBackup.cend(); it != end && !filtersWereChanged; ++it) {
                 if (!m_filterMap.contains(it.key())) {
                     filtersWereChanged = true;
                 } else {
-                    QStringList a = it.value();
-                    QStringList b = m_filterMap.value(it.key());
+                    const QStringList &a = it.value();
+                    const QStringList &b = m_filterMap.value(it.key());
                     if (a.count() != b.count()) {
                         filtersWereChanged = true;
                     } else {
-                        QStringList::const_iterator i(a.constBegin());
-                        while (i != a.constEnd()) {
-                            if (!b.contains(*i)) {
+                        for (const QString &aStr : a) {
+                            if (!b.contains(aStr)) {
                                 filtersWereChanged = true;
                                 break;
                             }
-                            ++i;
                         }
                     }
                 }
@@ -459,16 +451,13 @@ void PreferencesDialog::applyChanges()
     }
 
     if (filtersWereChanged) {
-        foreach (const QString &filter, m_removedFilters)
+        for (const QString &filter : qAsConst(m_removedFilters))
             helpEngine.removeCustomFilter(filter);
-        QMapIterator<QString, QStringList> it(m_filterMap);
-        while (it.hasNext()) {
-            it.next();
+        for (auto it = m_filterMap.cbegin(), end = m_filterMap.cend(); it != end; ++it)
             helpEngine.addCustomFilter(it.key(), it.value());
-        }
     }
 
-    foreach (const QString &doc, m_unregDocs) {
+    for (const QString &doc : qAsConst(m_unregDocs)) {
         OpenPagesManager::instance()->closePages(doc);
         helpEngine.unregisterDocumentation(doc);
     }
@@ -517,21 +506,21 @@ void PreferencesDialog::updateFontSettingsPage()
 
     m_browserFontPanel->setChecked(helpEngine.usesBrowserFont());
 
-    connect(m_appFontPanel, SIGNAL(toggled(bool)), this,
-        SLOT(appFontSettingToggled(bool)));
-    connect(m_browserFontPanel, SIGNAL(toggled(bool)), this,
-        SLOT(browserFontSettingToggled(bool)));
+    connect(m_appFontPanel, &QGroupBox::toggled,
+            this, &PreferencesDialog::appFontSettingToggled);
+    connect(m_browserFontPanel, &QGroupBox::toggled,
+            this, &PreferencesDialog::browserFontSettingToggled);
 
-    QList<QComboBox*> allCombos = m_appFontPanel->findChildren<QComboBox*>();
-    foreach (QComboBox* box, allCombos) {
-        connect(box, SIGNAL(currentIndexChanged(int)), this,
-            SLOT(appFontSettingChanged(int)));
+    const QList<QComboBox*> &appCombos = m_appFontPanel->findChildren<QComboBox*>();
+    for (QComboBox* box : appCombos) {
+        connect(box, QOverload<int>::of(&QComboBox::currentIndexChanged),
+                this, &PreferencesDialog::appFontSettingChanged);
     }
 
-    allCombos = m_browserFontPanel->findChildren<QComboBox*>();
-    foreach (QComboBox* box, allCombos) {
-        connect(box, SIGNAL(currentIndexChanged(int)), this,
-            SLOT(browserFontSettingChanged(int)));
+    const QList<QComboBox*> &browserCombos = m_browserFontPanel->findChildren<QComboBox*>();
+    for (QComboBox* box : browserCombos) {
+        connect(box, QOverload<int>::of(&QComboBox::currentIndexChanged),
+                this, &PreferencesDialog::browserFontSettingChanged);
     }
 }
 
@@ -574,9 +563,12 @@ void PreferencesDialog::updateOptionsPage()
     m_showTabs = helpEngine.showTabs();
     m_ui.showTabs->setChecked(m_showTabs);
 
-    connect(m_ui.blankPageButton, SIGNAL(clicked()), this, SLOT(setBlankPage()));
-    connect(m_ui.currentPageButton, SIGNAL(clicked()), this, SLOT(setCurrentPage()));
-    connect(m_ui.defaultPageButton, SIGNAL(clicked()), this, SLOT(setDefaultPage()));
+    connect(m_ui.blankPageButton, &QAbstractButton::clicked,
+            this, &PreferencesDialog::setBlankPage);
+    connect(m_ui.currentPageButton, &QAbstractButton::clicked,
+            this, &PreferencesDialog::setCurrentPage);
+    connect(m_ui.defaultPageButton, &QAbstractButton::clicked,
+            this, &PreferencesDialog::setDefaultPage);
 }
 
 void PreferencesDialog::setBlankPage()
