@@ -53,8 +53,7 @@ TopicChooser::TopicChooser(QWidget *parent, const QString &keyword, const QMap<Q
     m_filterModel->setSourceModel(model);
     m_filterModel->setFilterCaseSensitivity(Qt::CaseInsensitive);
 
-    QMap<QString, QUrl>::const_iterator it = links.constBegin();
-    for (; it != links.constEnd(); ++it) {
+    for (auto it = links.cbegin(), end = links.cend(); it != end; ++it) {
         m_links.append(it.value());
         QStandardItem *item = new QStandardItem(it.key());
         item->setToolTip(it.value().toString());
@@ -68,10 +67,14 @@ TopicChooser::TopicChooser(QWidget *parent, const QString &keyword, const QMap<Q
     if (m_filterModel->rowCount() != 0)
         ui.listWidget->setCurrentIndex(m_filterModel->index(0, 0));
 
-    connect(ui.buttonCancel, SIGNAL(clicked()), this, SLOT(reject()));
-    connect(ui.buttonDisplay, SIGNAL(clicked()), this, SLOT(acceptDialog()));
-    connect(ui.lineEdit, SIGNAL(textChanged(QString)), this, SLOT(setFilter(QString)));
-    connect(ui.listWidget, SIGNAL(activated(QModelIndex)), this, SLOT(activated(QModelIndex)));
+    connect(ui.buttonCancel, &QAbstractButton::clicked,
+            this, &QDialog::reject);
+    connect(ui.buttonDisplay, &QAbstractButton::clicked,
+            this, &TopicChooser::acceptDialog);
+    connect(ui.lineEdit, &QLineEdit::textChanged,
+            this, &TopicChooser::setFilter);
+    connect(ui.listWidget, &QAbstractItemView::activated,
+            this, &TopicChooser::activated);
 
     const QByteArray ba = HelpEngineWrapper::instance().topicChooserGeometry();
     if (!ba.isEmpty())
