@@ -43,57 +43,43 @@ QT_BEGIN_NAMESPACE
 
 namespace fulltextsearch {
 
-QHelpSearchIndexReader::QHelpSearchIndexReader()
-    : QThread()
-    , m_cancel(false)
-{
-    // nothing todo
-}
-
 QHelpSearchIndexReader::~QHelpSearchIndexReader()
 {
-    mutex.lock();
-    this->m_cancel = true;
-    mutex.unlock();
-
+    cancelSearching();
     wait();
 }
 
 void QHelpSearchIndexReader::cancelSearching()
 {
-    mutex.lock();
-    this->m_cancel = true;
-    mutex.unlock();
+    QMutexLocker lock(&m_mutex);
+    m_cancel = true;
 }
 
 void QHelpSearchIndexReader::search(const QString &collectionFile, const QString &indexFilesFolder,
-    const QList<QHelpSearchQuery> &queryList)
+    const QString &searchInput)
 {
     wait();
 
-    this->hitList.clear();
-    this->m_cancel = false;
-    this->m_query = queryList;
-    this->m_collectionFile = collectionFile;
-    this->m_indexFilesFolder = indexFilesFolder;
+    m_searchResults.clear();
+    m_cancel = false;
+    m_searchInput = searchInput;
+    m_collectionFile = collectionFile;
+    m_indexFilesFolder = indexFilesFolder;
 
     start(QThread::NormalPriority);
 }
 
-int QHelpSearchIndexReader::hitCount() const
+int QHelpSearchIndexReader::searchResultCount() const
 {
-    QMutexLocker lock(&mutex);
-    return hitList.count();
+    QMutexLocker lock(&m_mutex);
+    return m_searchResults.count();
 }
 
-QList<QHelpSearchEngine::SearchHit> QHelpSearchIndexReader::hits(int start,
+QVector<QHelpSearchResult> QHelpSearchIndexReader::searchResults(int start,
                                                                  int end) const
 {
-    QList<QHelpSearchEngine::SearchHit> hits;
-    QMutexLocker lock(&mutex);
-    for (int i = start; i < end && i < hitList.count(); ++i)
-        hits.append(hitList.at(i));
-    return hits;
+    QMutexLocker lock(&m_mutex);
+    return m_searchResults.mid(start, end - start);
 }
 
 
