@@ -41,10 +41,10 @@ PathPage::PathPage(QWidget *parent)
         "matched by the file filter will be included."));
 
     m_ui.setupUi(this);
-    connect(m_ui.addButton, SIGNAL(clicked()),
-        this, SLOT(addPath()));
-    connect(m_ui.removeButton, SIGNAL(clicked()),
-        this, SLOT(removePath()));
+    connect(m_ui.addButton, &QAbstractButton::clicked,
+            this, &PathPage::addPath);
+    connect(m_ui.removeButton, &QAbstractButton::clicked,
+            this, &PathPage::removePath);
 
     m_ui.filterLineEdit->setText(QLatin1String("*.html, *.htm, *.png, *.jpg, *.css"));
 
@@ -65,7 +65,7 @@ void PathPage::setPath(const QString &path)
 QStringList PathPage::paths() const
 {
     QStringList lst;
-    for (int i = 0; i<m_ui.pathListWidget->count(); ++i)
+    for (int i = 0; i < m_ui.pathListWidget->count(); ++i)
         lst.append(m_ui.pathListWidget->item(i)->text());
     return lst;
 }
@@ -73,7 +73,7 @@ QStringList PathPage::paths() const
 QStringList PathPage::filters() const
 {
     QStringList lst;
-    foreach (const QString &s, m_ui.filterLineEdit->text().split(QLatin1Char(','))) {
+    for (const QString &s : m_ui.filterLineEdit->text().split(QLatin1Char(','))) {
         lst.append(s.trimmed());
     }
     return lst;
