@@ -30,10 +30,10 @@
 #define FORMWINDOW_H
 
 #include "formeditor_global.h"
-#include "qdesignerundostack.h"
 #include <formwindowbase_p.h>
 
 // Qt
+#include <QtWidgets/QUndoStack>
 #include <QtCore/QHash>
 #include <QtCore/QList>
 #include <QtCore/QMap>
@@ -70,6 +70,13 @@ class QT_FORMEDITOR_EXPORT FormWindow: public FormWindowBase
     Q_OBJECT
 
 public:
+    enum HandleOperation
+    {
+        NoHandleOperation,
+        ResizeHandleOperation,
+        ChangeLayoutSpanHandleOperation
+    };
+
     explicit FormWindow(FormEditor *core, QWidget *parent = 0, Qt::WindowFlags flags = 0);
     virtual ~FormWindow();
 
@@ -199,6 +206,9 @@ public:
 
     bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
 
+    HandleOperation handleOperation() const { return m_handleOperation; }
+    void setHandleOperation(HandleOperation o) { m_handleOperation = o; }
+
 signals:
     void contextMenuRequested(QMenu *menu, QWidget *widget);
 
@@ -230,6 +240,7 @@ private slots:
     void checkSelection();
     void checkSelectionNow();
     void slotSelectWidget(QAction *);
+    void slotCleanChanged(bool);
 
 private:
     enum MouseState {
@@ -325,7 +336,7 @@ private:
 
     QPoint m_startPos;
 
-    QDesignerUndoStack m_undoStack;
+    QUndoStack m_undoStack;
 
     QString m_fileName;
 
@@ -353,6 +364,7 @@ private:
     QStringList m_includeHints;
 
     QPoint m_contextMenuPosition;
+    HandleOperation m_handleOperation = NoHandleOperation;
 
 private:
     friend class WidgetEditorTool;
