@@ -43,18 +43,16 @@ namespace qdesigner_internal {
 
 // Data structure containing form dialog data providing comparison
 struct FormWindowData {
-    FormWindowData();
-
     bool equals(const FormWindowData&) const;
 
     void fromFormWindow(FormWindowBase* fw);
     void applyToFormWindow(FormWindowBase* fw) const;
 
-    bool layoutDefaultEnabled;
-    int defaultMargin;
-    int defaultSpacing;
+    bool layoutDefaultEnabled{false};
+    int defaultMargin{0};
+    int defaultSpacing{0};
 
-    bool layoutFunctionsEnabled;
+    bool layoutFunctionsEnabled{false};
     QString marginFunction;
     QString spacingFunction;
 
@@ -64,7 +62,7 @@ struct FormWindowData {
 
     QStringList includeHints;
 
-    bool hasFormGrid;
+    bool hasFormGrid{false};
     Grid grid;
 };
 
@@ -81,15 +79,6 @@ QDebug operator<<(QDebug str, const  FormWindowData &d)
     return str;
 }
 
-FormWindowData::FormWindowData() :
-    layoutDefaultEnabled(false),
-    defaultMargin(0),
-    defaultSpacing(0),
-    layoutFunctionsEnabled(false),
-    hasFormGrid(false)
-{
-}
-
 bool FormWindowData::equals(const FormWindowData &rhs) const
 {
     return layoutDefaultEnabled   == rhs.layoutDefaultEnabled &&
@@ -247,7 +236,7 @@ void FormWindowSettings::setData(const FormWindowData &data)
     if (data.includeHints.empty()) {
         m_ui->includeHintsTextEdit->clear();
     } else {
-        m_ui->includeHintsTextEdit->setText(data.includeHints.join(QStringLiteral("\n")));
+        m_ui->includeHintsTextEdit->setText(data.includeHints.join(QLatin1Char('\n')));
     }
 
     m_ui->gridPanel->setChecked(data.hasFormGrid);
