@@ -76,7 +76,7 @@ AbstractItemEditor::AbstractItemEditor(QDesignerFormWindowInterface *form, QWidg
     m_editorFactory = new DesignerEditorFactory(form->core(), this);
     m_editorFactory->setSpacing(0);
     m_propertyBrowser = new ItemPropertyBrowser;
-    m_propertyBrowser->setFactoryForManager((QtVariantPropertyManager *)m_propertyManager,
+    m_propertyBrowser->setFactoryForManager(static_cast<QtVariantPropertyManager *>(m_propertyManager),
                                             m_editorFactory);
 
     connect(m_editorFactory, &DesignerEditorFactory::resetProperty,
@@ -168,7 +168,7 @@ void AbstractItemEditor::propertyChanged(QtProperty *property)
         // Subproperty
         return;
 
-    if ((role == ItemFlagsShadowRole && prop->value().toInt() == (int)QListWidgetItem().flags())
+    if ((role == ItemFlagsShadowRole && prop->value().toInt() == int(QListWidgetItem().flags()))
         || (role == Qt::DecorationPropertyRole && !qvariant_cast<PropertySheetIconValue>(prop->value()).mask())
         || (role == Qt::FontRole && !qvariant_cast<QFont>(prop->value()).resolve())) {
         prop->setModified(false);
@@ -214,9 +214,9 @@ void AbstractItemEditor::resetProperty(QtProperty *property)
     QtVariantProperty *prop = m_propertyManager->variantProperty(property);
     int role = m_propertyToRole.value(prop);
     if (role == ItemFlagsShadowRole)
-        prop->setValue(QVariant::fromValue((int)QListWidgetItem().flags()));
+        prop->setValue(QVariant::fromValue(int(QListWidgetItem().flags())));
     else
-        prop->setValue(QVariant(prop->valueType(), (void *)0));
+        prop->setValue(QVariant(prop->valueType(), nullptr));
     prop->setModified(false);
 
     setItemData(role, QVariant());
@@ -241,14 +241,14 @@ void AbstractItemEditor::cacheReloaded()
 void AbstractItemEditor::updateBrowser()
 {
     BoolBlocker block(m_updatingBrowser);
-    foreach (QtVariantProperty *prop, m_properties) {
+    for (QtVariantProperty *prop : qAsConst(m_properties)) {
         int role = m_propertyToRole.value(prop);
         QVariant val = getItemData(role);
         if (!val.isValid()) {
             if (role == ItemFlagsShadowRole)
-                val = QVariant::fromValue((int)QListWidgetItem().flags());
+                val = QVariant::fromValue(int(QListWidgetItem().flags()));
             else
-                val = QVariant((int)prop->value().userType(), (void *)0);
+                val = QVariant(int(prop->value().userType()), nullptr);
             prop->setModified(false);
         } else {
             prop->setModified(true);
@@ -256,9 +256,10 @@ void AbstractItemEditor::updateBrowser()
         prop->setValue(val);
     }
 
-    if (m_propertyBrowser->topLevelItems().isEmpty())
-        foreach (QtVariantProperty *prop, m_rootProperties)
+    if (m_propertyBrowser->topLevelItems().isEmpty()) {
+        for (QtVariantProperty *prop : qAsConst(m_rootProperties))
             m_propertyBrowser->addProperty(prop);
+    }
 }
 
 void AbstractItemEditor::injectPropertyBrowser(QWidget *parent, QWidget *widget)
