@@ -67,7 +67,6 @@ static const char *defaultTypeValueC = "default";
 static const char *customValueC = "custom";
 static const char *iconPrefixC = "__qt_icon__";
 static const char *scratchPadValueC = "scratchpad";
-static const char *qtLogoC = "qtlogo.png";
 static const char *invisibleNameC = "[invisible]";
 
 enum TopLevelRole  { NORMAL_ITEM, SCRATCHPAD_ITEM, CUSTOM_ITEM };
@@ -110,7 +109,7 @@ WidgetBoxTreeWidget::WidgetBoxTreeWidget(QDesignerFormEditorInterface *core, QWi
 QIcon WidgetBoxTreeWidget::iconForWidget(QString iconName) const
 {
     if (iconName.isEmpty())
-        iconName = QLatin1String(qtLogoC);
+        return qdesigner_internal::qtLogoIcon();
 
     if (iconName.startsWith(QLatin1String(iconPrefixC))) {
         const IconCache::const_iterator it = m_pluginIcons.constFind(iconName);
@@ -315,7 +314,7 @@ bool WidgetBoxTreeWidget::loadContents(const QString &contents)
         return false;
     }
 
-    foreach(const Category &cat, cat_list)
+    for (const Category &cat : qAsConst(cat_list))
         addCategory(cat);
 
     addCustomCategories(false);
@@ -549,7 +548,7 @@ void WidgetBoxTreeWidget::writeCategories(QXmlStreamWriter &writer, const Catego
 
     writer.writeStartElement(widgetbox);
 
-    foreach (const Category &cat, cat_list) {
+    for (const Category &cat : cat_list) {
         writer.writeStartElement(category);
         writer.writeAttribute(name, cat.name());
         if (cat.type() == Category::Scratchpad)
@@ -584,7 +583,7 @@ void WidgetBoxTreeWidget::writeCategories(QXmlStreamWriter &writer, const Catego
 static int findCategory(const QString &name, const WidgetBoxTreeWidget::CategoryList &list)
 {
     int idx = 0;
-    foreach (const WidgetBoxTreeWidget::Category &cat, list) {
+    for (const WidgetBoxTreeWidget::Category &cat : list) {
         if (cat.name() == name)
             return idx;
         ++idx;
@@ -616,7 +615,7 @@ WidgetBoxTreeWidget::CategoryList WidgetBoxTreeWidget::loadCustomCategoryList()
     const QString invisible = QLatin1String(invisibleNameC);
     const QString iconPrefix = QLatin1String(iconPrefixC);
 
-    foreach(QDesignerCustomWidgetInterface *c, customWidgets) {
+    for (QDesignerCustomWidgetInterface *c : customWidgets) {
         const QString dom_xml = c->domXml();
         if (dom_xml.isEmpty())
             continue;
@@ -647,8 +646,6 @@ WidgetBoxTreeWidget::CategoryList WidgetBoxTreeWidget::loadCustomCategoryList()
             icon_name = iconPrefix;
             icon_name += pluginName;
             m_pluginIcons.insert(icon_name, icon);
-        } else {
-            icon_name = QLatin1String(qtLogoC);
         }
 
         cat.addWidget(Widget(displayName, dom_xml, icon_name, Widget::Custom));
@@ -911,7 +908,7 @@ void WidgetBoxTreeWidget::dropWidgets(const QList<QDesignerDnDItemInterface*> &i
     WidgetBoxCategoryListView *categoryView = 0;
     bool added = false;
 
-    foreach (QDesignerDnDItemInterface *item, item_list) {
+    for (QDesignerDnDItemInterface *item : item_list) {
         QWidget *w = item->widget();
         if (w == 0)
             continue;
@@ -928,7 +925,7 @@ void WidgetBoxTreeWidget::dropWidgets(const QList<QDesignerDnDItemInterface*> &i
         DomWidget *fakeTopLevel = dom_ui->takeElementWidget();
         DomWidget *firstWidget = 0;
         if (fakeTopLevel && !fakeTopLevel->elementWidget().isEmpty()) {
-            firstWidget = fakeTopLevel->elementWidget().first();
+            firstWidget = fakeTopLevel->elementWidget().constFirst();
             dom_ui->setElementWidget(firstWidget);
         } else {
             dom_ui->setElementWidget(fakeTopLevel);
