@@ -47,9 +47,7 @@ QDesignerServer::QDesignerServer(QObject *parent)
 {
     m_socket = 0;
     m_server = new QTcpServer(this);
-    m_server->listen(QHostAddress::LocalHost, 0);
-    if (m_server->isListening())
-    {
+    if (m_server->listen(QHostAddress::LocalHost, 0)) {
         connect(m_server, &QTcpServer::newConnection,
                 this, &QDesignerServer::handleNewConnection);
     }
@@ -70,8 +68,7 @@ void QDesignerServer::sendOpenRequest(int port, const QStringList &files)
     sSocket->connectToHost(QHostAddress::LocalHost, port);
     if(sSocket->waitForConnected(3000))
     {
-        foreach(const QString &file, files)
-        {
+        for (const QString &file : files) {
             QFileInfo fi(file);
             sSocket->write(fi.absoluteFilePath().toUtf8() + '\n');
         }
