@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -275,21 +270,18 @@ void QDesignerWorkbench::saveGeometriesForModeChange()
         break;
     case TopLevelMode: {
         const QPoint desktopOffset = QApplication::desktop()->availableGeometry().topLeft();
-        foreach (QDesignerToolWindow *tw, m_toolWindows)
+        for (QDesignerToolWindow *tw : qAsConst(m_toolWindows))
             m_Positions.insert(tw, Position(tw, desktopOffset));
-        foreach (QDesignerFormWindow *fw, m_formWindows) {
+        for (QDesignerFormWindow *fw : qAsConst(m_formWindows))
             m_Positions.insert(fw,  Position(fw, desktopOffset));
-        }
     }
         break;
     case DockedMode: {
         const QPoint mdiAreaOffset = m_dockedMainWindow->mdiArea()->pos();
-        foreach (QDesignerToolWindow *tw, m_toolWindows) {
+        for (QDesignerToolWindow *tw : qAsConst(m_toolWindows))
             m_Positions.insert(tw, Position(dockWidgetOf(tw)));
-        }
-        foreach (QDesignerFormWindow *fw, m_formWindows) {
+        for (QDesignerFormWindow *fw : qAsConst(m_formWindows))
             m_Positions.insert(fw, Position(mdiSubWindowOf(fw), mdiAreaOffset));
-        }
     }
         break;
     }
@@ -327,7 +319,7 @@ Qt::WindowFlags QDesignerWorkbench::magicalWindowFlags(const QWidget *widgetForF
 {
     switch (m_mode) {
         case TopLevelMode: {
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
             if (qobject_cast<const QDesignerToolWindow *>(widgetForFlags))
                 return Qt::Tool;
 #else
@@ -379,17 +371,17 @@ void QDesignerWorkbench::switchToNeutralMode()
 
     m_mode = NeutralMode;
 
-    foreach (QDesignerToolWindow *tw, m_toolWindows) {
+    for (QDesignerToolWindow *tw : qAsConst(m_toolWindows)) {
         tw->setCloseEventPolicy(MainWindowBase::AcceptCloseEvents);
         tw->setParent(0);
     }
 
-    foreach (QDesignerFormWindow *fw, m_formWindows) {
+    for (QDesignerFormWindow *fw : qAsConst(m_formWindows)) {
         fw->setParent(0);
         fw->setMaximumSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
     }
 
-#ifndef Q_OS_MAC
+#ifndef Q_OS_MACOS
     m_globalMenuBar->setParent(0);
 #endif
 
@@ -407,14 +399,14 @@ void QDesignerWorkbench::switchToDockedMode()
 
     switchToNeutralMode();
 
-#if !defined(Q_OS_MAC)
+#if !defined(Q_OS_MACOS)
 #    if defined(Q_OS_UNIX)
     QApplication::setAttribute(Qt::AA_DontUseNativeMenuBar, false);
 #    endif // Q_OS_UNIX
     QDesignerToolWindow *widgetBoxWrapper = widgetBoxToolWindow();
     widgetBoxWrapper->action()->setVisible(true);
     widgetBoxWrapper->setWindowTitle(tr("Widget Box"));
-#endif // !Q_OS_MAC
+#endif // !Q_OS_MACOS
 
     m_mode = DockedMode;
     const QDesignerSettings settings(m_core);
@@ -431,13 +423,13 @@ void QDesignerWorkbench::switchToDockedMode()
 
     m_core->setTopLevel(m_dockedMainWindow);
 
-#ifndef Q_OS_MAC
+#ifndef Q_OS_MACOS
     m_dockedMainWindow->setMenuBar(m_globalMenuBar);
     m_globalMenuBar->show();
 #endif
     qDesigner->setMainWindow(m_dockedMainWindow);
 
-    foreach (QDesignerFormWindow *fw, m_formWindows) {
+    for (QDesignerFormWindow *fw : qAsConst(m_formWindows)) {
         QMdiSubWindow *subwin = m_dockedMainWindow->createMdiSubWindow(fw, magicalWindowFlags(fw),
                                                                        m_actionManager->closeFormAction()->shortcut());
         subwin->hide();
@@ -457,7 +449,7 @@ void QDesignerWorkbench::adjustMDIFormPositions()
 {
     const QPoint mdiAreaOffset = m_dockedMainWindow->mdiArea()->pos();
 
-    foreach (QDesignerFormWindow *fw, m_formWindows) {
+    for (QDesignerFormWindow *fw : qAsConst(m_formWindows)) {
         const PositionMap::const_iterator pit = m_Positions.constFind(fw);
         if (pit != m_Positions.constEnd())
             pit->applyTo(mdiSubWindowOf(fw), mdiAreaOffset);
@@ -480,7 +472,7 @@ void QDesignerWorkbench::switchToTopLevelMode()
     // The widget box is special, it gets the menubar and gets to be the main widget.
 
     m_core->setTopLevel(widgetBoxWrapper);
-#if !defined(Q_OS_MAC)
+#if !defined(Q_OS_MACOS)
 #    if defined(Q_OS_UNIX)
     // For now the appmenu protocol does not make it possible to associate a
     // menubar with all application windows. This means in top level mode you
@@ -494,7 +486,7 @@ void QDesignerWorkbench::switchToTopLevelMode()
     widgetBoxWrapper->setCloseEventPolicy(MainWindowBase::EmitCloseEventSignal);
     qDesigner->setMainWindow(widgetBoxWrapper);
     widgetBoxWrapper->setWindowTitle(MainWindowBase::mainWindowTitle());
-#endif // !Q_OS_MAC
+#endif // !Q_OS_MACOS
 
     const QDesignerSettings settings(m_core);
     m_topLevelData.toolbars = MainWindowBase::createToolBars(m_actionManager, false);
@@ -511,7 +503,7 @@ void QDesignerWorkbench::switchToTopLevelMode()
     widgetBoxWrapper->restoreState(settings.mainWindowState(m_mode), MainWindowBase::settingsVersion());
 
     bool found_visible_window = false;
-    foreach (QDesignerToolWindow *tw, m_toolWindows) {
+    for (QDesignerToolWindow *tw : qAsConst(m_toolWindows)) {
         tw->setParent(magicalParent(tw), magicalWindowFlags(tw));
         settings.restoreGeometry(tw, tw->geometryHint());
         tw->action()->setChecked(tw->isVisible());
@@ -523,7 +515,7 @@ void QDesignerWorkbench::switchToTopLevelMode()
 
     m_actionManager->setBringAllToFrontVisible(true);
 
-    foreach (QDesignerFormWindow *fw, m_formWindows) {
+    for (QDesignerFormWindow *fw : qAsConst(m_formWindows)) {
         fw->setParent(magicalParent(fw), magicalWindowFlags(fw));
         fw->setAttribute(Qt::WA_DeleteOnClose, true);
         const PositionMap::const_iterator pit = m_Positions.constFind(fw);
@@ -633,7 +625,7 @@ void QDesignerWorkbench::initializeCorePlugins()
     QList<QObject*> plugins = QPluginLoader::staticInstances();
     plugins += core()->pluginManager()->instances();
 
-    foreach (QObject *plugin, plugins) {
+    for (QObject *plugin : qAsConst(plugins)) {
         if (QDesignerFormEditorPluginInterface *formEditorPlugin = qobject_cast<QDesignerFormEditorPluginInterface*>(plugin)) {
             if (!formEditorPlugin->isInitialized())
                 formEditorPlugin->initialize(core());
@@ -658,7 +650,7 @@ void QDesignerWorkbench::saveGeometries(QDesignerSettings &settings) const
     case TopLevelMode:
         settings.setToolBarsState(m_mode, m_topLevelData.toolbarManager->saveState(MainWindowBase::settingsVersion()));
         settings.setMainWindowState(m_mode, widgetBoxToolWindow()->saveState(MainWindowBase::settingsVersion()));
-        foreach (const QDesignerToolWindow *tw, m_toolWindows)
+        for (const QDesignerToolWindow *tw : m_toolWindows)
             settings.saveGeometryFor(tw);
         break;
     case NeutralMode:
@@ -688,7 +680,7 @@ bool QDesignerWorkbench::saveForm(QDesignerFormWindowInterface *frm)
 
 QDesignerFormWindow *QDesignerWorkbench::findFormWindow(QWidget *widget) const
 {
-    foreach (QDesignerFormWindow *formWindow, m_formWindows) {
+    for (QDesignerFormWindow *formWindow : m_formWindows) {
         if (formWindow->editor() == widget)
             return formWindow;
     }
@@ -700,7 +692,7 @@ bool QDesignerWorkbench::handleClose()
 {
     m_state = StateClosing;
     QList<QDesignerFormWindow *> dirtyForms;
-    foreach (QDesignerFormWindow *w, m_formWindows) {
+    for (QDesignerFormWindow *w : qAsConst(m_formWindows)) {
         if (w->editor()->isDirty())
             dirtyForms << w;
     }
@@ -727,7 +719,7 @@ bool QDesignerWorkbench::handleClose()
                 m_state = StateUp;
                 return false;
             case QMessageBox::Save:
-               foreach (QDesignerFormWindow *fw, dirtyForms) {
+               for (QDesignerFormWindow *fw : qAsConst(dirtyForms)) {
                    fw->show();
                    fw->raise();
                    if (!fw->close()) {
@@ -737,7 +729,7 @@ bool QDesignerWorkbench::handleClose()
                }
                break;
             case QMessageBox::Discard:
-              foreach (QDesignerFormWindow *fw, dirtyForms) {
+              for (QDesignerFormWindow *fw : qAsConst(dirtyForms)) {
                   fw->editor()->setDirty(false);
                   fw->setWindowModified(false);
               }
@@ -746,7 +738,7 @@ bool QDesignerWorkbench::handleClose()
         }
     }
 
-    foreach (QDesignerFormWindow *fw, m_formWindows)
+    for (QDesignerFormWindow *fw : qAsConst(m_formWindows))
         fw->close();
 
     saveSettings();
@@ -804,7 +796,7 @@ void QDesignerWorkbench::formWindowActionTriggered(QAction *a)
 
 void QDesignerWorkbench::closeAllToolWindows()
 {
-    foreach (QDesignerToolWindow *tw, m_toolWindows)
+    for (QDesignerToolWindow *tw : qAsConst(m_toolWindows))
         tw->hide();
 }
 
@@ -823,10 +815,7 @@ bool QDesignerWorkbench::readInBackup()
         return false;
 
     const QString modifiedPlaceHolder = QStringLiteral("[*]");
-    QMapIterator<QString, QString> it(backupFileMap);
-    while(it.hasNext()) {
-        it.next();
-
+    for (auto it = backupFileMap.cbegin(), end = backupFileMap.cend(); it != end; ++it) {
         QString fileName = it.key();
         fileName.remove(modifiedPlaceHolder);
 
@@ -861,9 +850,9 @@ void QDesignerWorkbench::bringAllToFront()
 {
     if (m_mode !=  TopLevelMode)
         return;
-    foreach(QDesignerToolWindow *tw, m_toolWindows)
+    for (QDesignerToolWindow *tw : qAsConst(m_toolWindows))
         raiseWindow(tw);
-    foreach(QDesignerFormWindow *dfw, m_formWindows)
+    for (QDesignerFormWindow *dfw : qAsConst(m_formWindows))
         raiseWindow(dfw);
 }
 
@@ -1100,7 +1089,7 @@ void QDesignerWorkbench::restoreUISettings()
     if (font == m_toolWindows.front()->font())
         return;
 
-    foreach(QDesignerToolWindow *tw, m_toolWindows)
+    for (QDesignerToolWindow *tw : qAsConst(m_toolWindows))
         tw->setFont(font);
 }
 
