@@ -64,7 +64,7 @@
 #include <QtGui/QContextMenuEvent>
 #include <QtCore/QItemSelection>
 
-#include <QtCore/QRegExp>
+#include <QtCore/QRegularExpression>
 #include <QtCore/QDebug>
 #include <QtCore/QBuffer>
 
@@ -101,6 +101,8 @@ public:
 };
 
 //--------  ActionEditor
+ObjectNamingMode ActionEditor::m_objectNamingMode = Underscore; // fixme Qt 6: CamelCase
+
 ActionEditor::ActionEditor(QDesignerFormEditorInterface *core, QWidget *parent, Qt::WindowFlags flags) :
     QDesignerActionEditorInterface(parent, flags),
     m_core(core),
@@ -285,7 +287,7 @@ void ActionEditor::setFormWindow(QDesignerFormWindowInterface *formWindow)
 
     if (m_formWindow != 0) {
         const ActionList actionList = m_formWindow->mainContainer()->findChildren<QAction*>();
-        foreach (QAction *action, actionList)
+        for (QAction *action : actionList)
             disconnect(action, &QAction::changed, this, &ActionEditor::slotActionChanged);
     }
 
@@ -310,7 +312,7 @@ void ActionEditor::setFormWindow(QDesignerFormWindowInterface *formWindow)
     m_filterWidget->setEnabled(true);
 
     const ActionList actionList = formWindow->mainContainer()->findChildren<QAction*>();
-    foreach (QAction *action, actionList)
+    for (QAction *action : actionList)
         if (!action->isSeparator() && core()->metaDataBase()->item(action) != 0) {
             // Show unless it has a menu. However, listen for change on menu actions also as it might be removed
             if (!action->menu())
@@ -603,7 +605,7 @@ void ActionEditor::deleteActions(QDesignerFormWindowInterface *fw, const ActionL
     const QString description = actions.size() == 1 ?
         tr("Remove action '%1'").arg(actions.front()->objectName()) : tr("Remove actions");
     fw->beginCommand(description);
-    foreach(QAction *action, actions) {
+    for (QAction *action : actions) {
         RemoveActionCommand *cmd = new RemoveActionCommand(fw);
         cmd->init(action);
         fw->commandHistory()->push(cmd);
@@ -648,21 +650,61 @@ void ActionEditor::slotDelete()
     deleteActions(fw,  selection);
 }
 
+// UnderScore: "Open file" -> actionOpen_file
+static QString underscore(QString text)
+{
+    const QString underscore = QString(QLatin1Char('_'));
+    static const QRegularExpression nonAsciiPattern(QStringLiteral("[^a-zA-Z_0-9]"));
+    Q_ASSERT(nonAsciiPattern.isValid());
+    text.replace(nonAsciiPattern, underscore);
+    static const QRegularExpression multipleSpacePattern(QStringLiteral("__*"));
+    Q_ASSERT(multipleSpacePattern.isValid());
+    text.replace(multipleSpacePattern, underscore);
+    if (text.endsWith(underscore.at(0)))
+        text.chop(1);
+    return text;
+}
+
+// CamelCase: "Open file" -> actionOpenFile, ignoring non-ASCII letters.
+
+enum CharacterCategory { OtherCharacter, DigitOrAsciiLetter, NonAsciiLetter };
+
+static inline CharacterCategory category(QChar c)
+{
+    if (c.isDigit())
+        return DigitOrAsciiLetter;
+    if (c.isLetter()) {
+        const ushort uc = c.unicode();
+        return (uc >= 'a' && uc <= 'z') || (uc >= 'A' && uc <= 'Z')
+            ? DigitOrAsciiLetter : NonAsciiLetter;
+    }
+    return OtherCharacter;
+}
+
+static QString camelCase(const QString &text)
+{
+    QString result;
+    result.reserve(text.size());
+    bool lastCharAccepted = false;
+    for (QChar c : text) {
+        const CharacterCategory cat = category(c);
+        if (cat != NonAsciiLetter) {
+            const bool acceptable = cat == DigitOrAsciiLetter;
+            if (acceptable)
+                result.append(lastCharAccepted ? c : c.toUpper()); // New word starts
+            lastCharAccepted = acceptable;
+        }
+    }
+    return result;
+}
+
 QString ActionEditor::actionTextToName(const QString &text, const QString &prefix)
 {
     QString name = text;
     if (name.isEmpty())
         return QString();
+    return prefix + (m_objectNamingMode == CamelCase ? camelCase(text) : underscore(text));
 
-    name[0] = name.at(0).toUpper();
-    name.prepend(prefix);
-    const QString underscore = QString(QLatin1Char('_'));
-    name.replace(QRegExp(QString(QStringLiteral("[^a-zA-Z_0-9]"))), underscore);
-    name.replace(QRegExp(QStringLiteral("__*")), underscore);
-    if (name.endsWith(underscore.at(0)))
-        name.truncate(name.size() - 1);
-
-    return name;
 }
 
 void  ActionEditor::resourceImageDropped(const QString &path, QAction *action)
@@ -786,7 +828,7 @@ void ActionEditor::slotContextMenuRequested(QContextMenuEvent *e, QAction *item)
         const QWidgetList associatedWidgets = ActionModel::associatedWidgets(action);
         if (!associatedWidgets.empty()) {
             QMenu *associatedWidgetsSubMenu =  menu.addMenu(tr("Used In"));
-            foreach (QWidget *w, associatedWidgets) {
+            for (QWidget *w : associatedWidgets) {
                 associatedWidgetsSubMenu->addAction(w->objectName(),
                                                     this, [this, w] { this->slotSelectAssociatedWidget(w); });
             }
