@@ -29,6 +29,7 @@
 
 #include "plugindialog_p.h"
 #include "pluginmanager_p.h"
+#include "iconloader_p.h"
 
 #include <QtDesigner/QDesignerFormEditorInterface>
 #include <QtDesigner/QDesignerIntegrationInterface>
@@ -92,7 +93,7 @@ void PluginDialog::populateTreeWidget()
         QTreeWidgetItem *topLevelItem = setTopLevelItem(tr("Loaded Plugins"));
         QFont boldFont = topLevelItem->font(0);
 
-        foreach (const QString &fileName, fileNames) {
+        for (const QString &fileName : fileNames) {
             QPluginLoader loader(fileName);
             const QFileInfo fileInfo(fileName);
 
@@ -100,7 +101,8 @@ void PluginDialog::populateTreeWidget()
 
             if (QObject *plugin = loader.instance()) {
                 if (const QDesignerCustomWidgetCollectionInterface *c = qobject_cast<QDesignerCustomWidgetCollectionInterface*>(plugin)) {
-                    foreach (const QDesignerCustomWidgetInterface *p, c->customWidgets())
+                    const QList<QDesignerCustomWidgetInterface *> &collCustomWidgets = c->customWidgets();
+                    for (const QDesignerCustomWidgetInterface *p : collCustomWidgets)
                         setItem(pluginItem, p->name(), p->toolTip(), p->whatsThis(), p->icon());
                 } else {
                     if (const QDesignerCustomWidgetInterface *p = qobject_cast<QDesignerCustomWidgetInterface*>(plugin))
@@ -114,7 +116,7 @@ void PluginDialog::populateTreeWidget()
     if (!notLoadedPlugins.isEmpty()) {
         QTreeWidgetItem *topLevelItem = setTopLevelItem(tr("Failed Plugins"));
         const QFont boldFont = topLevelItem->font(0);
-        foreach (const QString &plugin, notLoadedPlugins) {
+        for (const QString &plugin : notLoadedPlugins) {
             const QString failureReason = pluginManager->failureReason(plugin);
             QTreeWidgetItem *pluginItem = setPluginItem(topLevelItem, plugin, boldFont);
             setItem(pluginItem, failureReason, failureReason, QString(), QIcon());
@@ -129,14 +131,6 @@ void PluginDialog::populateTreeWidget()
     }
 }
 
-QIcon PluginDialog::pluginIcon(const QIcon &icon)
-{
-    if (icon.isNull())
-        return QIcon(QStringLiteral(":/qt-project.org/formeditor/images/qtlogo.png"));
-
-    return icon;
-}
-
 QTreeWidgetItem* PluginDialog::setTopLevelItem(const QString &itemName)
 {
     QTreeWidgetItem *topLevelItem = new QTreeWidgetItem(ui.treeWidget);
@@ -170,7 +164,7 @@ void PluginDialog::setItem(QTreeWidgetItem *pluginItem, const QString &name,
     item->setText(0, name);
     item->setToolTip(0, toolTip);
     item->setWhatsThis(0, whatsThis);
-    item->setIcon(0, pluginIcon(icon));
+    item->setIcon(0, icon.isNull() ? qtLogoIcon() : icon);
 }
 
 void  PluginDialog::updateCustomWidgetPlugins()
