@@ -75,30 +75,6 @@
 
 QT_BEGIN_NAMESPACE
 
-static QMenuBar *findMenuBar(const QWidget *widget)
-{
-    const QList<QObject*> children = widget->children();
-    foreach (QObject *obj, widget->children()) {
-        if (QMenuBar *mb = qobject_cast<QMenuBar*>(obj)) {
-            return mb;
-        }
-    }
-
-    return 0;
-}
-
-static QStatusBar *findStatusBar(const QWidget *widget)
-{
-    const QList<QObject*> children = widget->children();
-    foreach (QObject *obj, widget->children()) {
-        if (QStatusBar *sb = qobject_cast<QStatusBar*>(obj)) {
-            return sb;
-        }
-    }
-
-    return 0;
-}
-
 static inline QAction *createSeparatorHelper(QObject *parent) {
     QAction *rc = new QAction(parent);
     rc->setSeparator(true);
@@ -112,9 +88,10 @@ static QString objName(const QDesignerFormEditorInterface *core, QObject *object
 
     const QString objectNameProperty = QStringLiteral("objectName");
     const int index = sheet->indexOf(objectNameProperty);
-    const qdesigner_internal::PropertySheetStringValue objectNameValue
-            = qvariant_cast<qdesigner_internal::PropertySheetStringValue>(sheet->property(index));
-    return objectNameValue.value();
+    const QVariant v = sheet->property(index);
+    if (v.canConvert<qdesigner_internal::PropertySheetStringValue>())
+        return v.value<qdesigner_internal::PropertySheetStringValue>().value();
+    return v.toString();
 }
 
 enum { ApplyMinimumWidth = 0x1, ApplyMinimumHeight = 0x2, ApplyMaximumWidth = 0x4, ApplyMaximumHeight = 0x8 };
@@ -471,7 +448,7 @@ void QDesignerTaskMenu::removeStatusBar()
         }
 
         DeleteStatusBarCommand *cmd = new DeleteStatusBarCommand(fw);
-        cmd->init(findStatusBar(mw));
+        cmd->init(mw->findChild<QStatusBar *>(QString(), Qt::FindDirectChildrenOnly));
         fw->commandHistory()->push(cmd);
     }
 }
@@ -487,16 +464,16 @@ QList<QAction*> QDesignerTaskMenu::taskActions() const
 
     if (const QMainWindow *mw = qobject_cast<const QMainWindow*>(formWindow->mainContainer()))  {
         if (isMainContainer || mw->centralWidget() == widget()) {
-            if (!findMenuBar(mw)) {
+            if (mw->findChild<QMenuBar *>(QString(), Qt::FindDirectChildrenOnly) == nullptr)
                 actions.append(d->m_addMenuBar);
-            }
 
             actions.append(d->m_addToolBar);
             // ### create the status bar
-            if (!findStatusBar(mw))
-                actions.append(d->m_addStatusBar);
-            else
+            if (mw->findChild<QStatusBar *>(QString(), Qt::FindDirectChildrenOnly))
                 actions.append(d->m_removeStatusBar);
+            else
+                actions.append(d->m_addStatusBar);
+
             actions.append(d->m_separator);
         }
     }
@@ -677,7 +654,7 @@ void QDesignerTaskMenu::navigateToSlot(QDesignerFormEditorInterface *core,
         qdesigner_internal::MetaDataBaseItem *item = metaDataBase->metaDataBaseItem(object);
         Q_ASSERT(item);
         const QStringList fakeSignals = item->fakeSignals();
-        foreach (const QString &fakeSignal, fakeSignals)
+        for (const QString &fakeSignal : fakeSignals)
             classToSignalList[item->customClassName()][fakeSignal] = QStringList();
     }
 
@@ -689,7 +666,7 @@ void QDesignerTaskMenu::navigateToSlot(QDesignerFormEditorInterface *core,
             if (index >= 0) {
                 WidgetDataBaseItem* item = static_cast<WidgetDataBaseItem*>(db->item(index));
                 const QStringList fakeSignals = item->fakeSignals();
-                foreach (const QString &fakeSignal, fakeSignals)
+                for (const QString &fakeSignal : fakeSignals)
                     classToSignalList[promotedClassName][fakeSignal] = QStringList();
             }
         }
@@ -731,14 +708,17 @@ void QDesignerTaskMenu::navigateToSlot(QDesignerFormEditorInterface *core,
 
     dialogUi.signalList->resizeColumnToContents(0);
 
-    if (selectSignalDialog.exec() == QDialog::Accepted) {
-        QTreeWidgetItem *selectedItem = dialogUi.signalList->selectedItems().first();
-        const QString signalSignature = selectedItem->text(0);
-        const QStringList parameterNames = qvariant_cast<QStringList>(selectedItem->data(0, Qt::UserRole));
+    if (selectSignalDialog.exec() != QDialog::Accepted)
+        return;
+    const QList<QTreeWidgetItem *> &selectedItems = dialogUi.signalList->selectedItems();
+    if (selectedItems.isEmpty())
+        return;
+    const QTreeWidgetItem *selectedItem = selectedItems.constFirst();
+    const QString signalSignature = selectedItem->text(0);
+    const QStringList parameterNames = qvariant_cast<QStringList>(selectedItem->data(0, Qt::UserRole));
 
-        // TODO: Check whether signal is connected to slot
-        core->integration()->emitNavigateToSlot(objectName, signalSignature, parameterNames);
-    }
+    // TODO: Check whether signal is connected to slot
+    core->integration()->emitNavigateToSlot(objectName, signalSignature, parameterNames);
 }
 
 // Add a command that takes over the value of the current geometry as
