@@ -459,7 +459,8 @@ static void insertPlugins(QObject *o, QMap<QString, QDesignerCustomWidgetInterfa
     }
     // step 2) try with a collection of plugins
     if (QDesignerCustomWidgetCollectionInterface *c = qobject_cast<QDesignerCustomWidgetCollectionInterface *>(o)) {
-        foreach (QDesignerCustomWidgetInterface *iface, c->customWidgets())
+        const auto &collectionCustomWidgets = c->customWidgets();
+        for (QDesignerCustomWidgetInterface *iface : collectionCustomWidgets)
             customWidgets->insert(iface->name(), iface);
     }
 }
@@ -471,11 +472,12 @@ void QFormBuilder::updateCustomWidgets()
 {
     d->m_customWidgets.clear();
 
-    foreach (const QString &path, d->m_pluginPaths) {
+#if QT_CONFIG(library)
+    for (const QString &path : qAsConst(d->m_pluginPaths)) {
         const QDir dir(path);
         const QStringList candidates = dir.entryList(QDir::Files);
 
-        foreach (const QString &plugin, candidates) {
+        for (const QString &plugin : candidates) {
             if (!QLibrary::isLibrary(plugin))
                 continue;
 
@@ -488,11 +490,12 @@ void QFormBuilder::updateCustomWidgets()
                 insertPlugins(loader.instance(), &d->m_customWidgets);
         }
     }
+#endif // QT_CONFIG(library)
+
     // Check statically linked plugins
     const QObjectList staticPlugins = QPluginLoader::staticInstances();
-    if (!staticPlugins.empty())
-        foreach (QObject *o, staticPlugins)
-            insertPlugins(o, &d->m_customWidgets);
+    for (QObject *o : staticPlugins)
+        insertPlugins(o, &d->m_customWidgets);
 }
 
 /*!
