@@ -5,7 +5,7 @@
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
@@ -14,13 +14,24 @@
 ** and conditions see https://www.qt.io/terms-conditions. For further
 ** information use the contact form at https://www.qt.io/contact-us.
 **
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
+**
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
 ** included in the packaging of this file. Please review the following
 ** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -121,7 +132,7 @@ QVariant TranslatingTextBuilder::toNativeValue(const QVariant &value) const
     if (value.canConvert<QUiTranslatableStringValue>()) {
         QUiTranslatableStringValue tsv = qvariant_cast<QUiTranslatableStringValue>(value);
         if (!m_trEnabled)
-            return QString::fromUtf8(tsv.value().data());
+            return QString::fromUtf8(tsv.value().constData());
         return QVariant::fromValue(
             QCoreApplication::translate(m_className, tsv.value(), tsv.comment()));
     }
@@ -214,7 +225,8 @@ public:
     virtual bool eventFilter(QObject *o, QEvent *event)
     {
         if (event->type() == QEvent::LanguageChange) {
-            foreach (const QByteArray &prop, o->dynamicPropertyNames()) {
+            const QList<QByteArray> &dynamicPropertyNames = o->dynamicPropertyNames();
+            for (const QByteArray &prop : dynamicPropertyNames) {
                 if (prop.startsWith(PROP_GENERIC_PREFIX)) {
                     const QByteArray propName = prop.mid(sizeof(PROP_GENERIC_PREFIX) - 1);
                     const QUiTranslatableStringValue tsv =
@@ -418,7 +430,7 @@ void FormBuilderPrivate::applyProperties(QObject *o, const QList<DomProperty*> &
     // (as they are "shadowed" by the property sheets in designer). So do the initial
     // translation here.
     bool anyTrs = false;
-    foreach (const DomProperty *p, properties) {
+    for (const DomProperty *p : properties) {
         QUiTranslatableStringValue strVal;
         const QString text = convertTranslatable(p, m_class, &strVal);
         if (text.isEmpty())
@@ -634,8 +646,10 @@ QUiLoader::QUiLoader(QObject *parent)
 #endif // QT_NO_DATASTREAM
     d->builder.loader = this;
 
+#if QT_CONFIG(library)
     QStringList paths;
-    foreach (const QString &path, QApplication::libraryPaths()) {
+    const QStringList &libraryPaths = QApplication::libraryPaths();
+    for (const QString &path : libraryPaths) {
         QString libPath = path;
         libPath  += QDir::separator();
         libPath  += QStringLiteral("designer");
@@ -643,6 +657,7 @@ QUiLoader::QUiLoader(QObject *parent)
     }
 
     d->builder.setPluginPath(paths);
+#endif // QT_CONFIG(library)
 }
 
 /*!
@@ -789,9 +804,9 @@ QStringList QUiLoader::availableWidgets() const
     d->setupWidgetMap();
     widget_map available = *g_widgets();
 
-    foreach (QDesignerCustomWidgetInterface *plugin, d->builder.customWidgets()) {
+    const auto &customWidgets = d->builder.customWidgets();
+    for (QDesignerCustomWidgetInterface *plugin : customWidgets)
         available.insert(plugin->name(), true);
-    }
 
     return available.keys();
 }
