@@ -93,6 +93,12 @@ bool Generator::qdocWriteQaPages_ = false;
 bool Generator::useOutputSubdirs_ = true;
 QmlTypeNode* Generator::qmlTypeContext_ = 0;
 
+static QRegExp tag("</?@[^>]*>");
+static QLatin1String amp("&amp;");
+static QLatin1String gt("&gt;");
+static QLatin1String lt("&lt;");
+static QLatin1String quot("&quot;");
+
 void Generator::startDebugging(const QString& message)
 {
     debugging_ = true;
@@ -121,12 +127,7 @@ void Generator::debug(const QString& message)
   available to the generator subclasses.
  */
 Generator::Generator()
-    : amp("&amp;"),
-      gt("&gt;"),
-      lt("&lt;"),
-      quot("&quot;"),
-      tag("</?@[^>]*>"),
-      inLink_(false),
+    : inLink_(false),
       inContents_(false),
       inSectionHeading_(false),
       inTableHeader_(false),
@@ -936,7 +937,7 @@ void Generator::generateBody(const Node *node, CodeMarker *marker)
                                 }
                             }
                         }
-                        if (needWarning && !func->isReimplemented())
+                        if (needWarning && !func->isReimplemented() && !func->isOverload())
                             node->doc().location().warning(
                                         tr("Undocumented parameter '%1' in %2")
                                         .arg(*a).arg(node->plainFullName()));
@@ -1086,10 +1087,7 @@ void Generator::generateInherits(const ClassNode *classe, CodeMarker *marker)
         index = 0;
         while (r != classe->baseClasses().constEnd()) {
             if ((*r).node_) {
-                text << Atom(Atom::LinkNode, CodeMarker::stringForNode((*r).node_))
-                     << Atom(Atom::FormattingLeft, ATOM_FORMATTING_LINK)
-                     << Atom(Atom::String, (*r).signature_)
-                     << Atom(Atom::FormattingRight, ATOM_FORMATTING_LINK);
+                appendFullName(text, (*r).node_, classe);
 
                 if ((*r).access_ == Node::Protected) {
                     text << " (protected)";
@@ -1535,6 +1533,7 @@ void Generator::generateThreadSafeness(const Node *node, CodeMarker *marker)
                 text << tlink;
             else
                 text << rlink;
+            text << ".";
         }
         text << Atom::ParaRight;
         break;
@@ -2270,6 +2269,10 @@ QString Generator::typeString(const Node *node)
         return "QML signal handler";
     case Node::QmlMethod:
         return "QML method";
+    case Node::Module:
+        return "module";
+    case Node::QmlModule:
+        return "QML module";
     default:
         return "documentation";
     }
