@@ -75,6 +75,39 @@ void Node::initialize()
 
 bool Node::nodeNameLessThan(const Node *n1, const Node *n2)
 {
+    if (n1->isDocumentNode() && n2->isDocumentNode()) {
+        const DocumentNode* f1 = static_cast<const DocumentNode*>(n1);
+        const DocumentNode* f2 = static_cast<const DocumentNode*>(n2);
+        if (f1->fullTitle() < f2->fullTitle())
+            return true;
+        else if (f1->fullTitle() > f2->fullTitle())
+            return false;
+    }
+
+    if (n1->isCollectionNode() && n2->isCollectionNode()) {
+        const CollectionNode* f1 = static_cast<const CollectionNode*>(n1);
+        const CollectionNode* f2 = static_cast<const CollectionNode*>(n2);
+        if (f1->fullTitle() < f2->fullTitle())
+            return true;
+        else if (f1->fullTitle() > f2->fullTitle())
+            return false;
+    }
+
+    if (n1->type() == Node::Function && n2->type() == Node::Function) {
+        const FunctionNode* f1 = static_cast<const FunctionNode*>(n1);
+        const FunctionNode* f2 = static_cast<const FunctionNode*>(n2);
+
+        if (f1->isConst() < f2->isConst())
+            return true;
+        else if (f1->isConst() > f2->isConst())
+            return false;
+
+        if (f1->signature(false) < f2->signature(false))
+            return true;
+        else if (f1->signature(false) > f2->signature(false))
+            return false;
+    }
+
     if (n1->location().filePath() < n2->location().filePath())
         return true;
     else if (n1->location().filePath() > n2->location().filePath())
@@ -95,38 +128,6 @@ bool Node::nodeNameLessThan(const Node *n1, const Node *n2)
     else if (n1->access() > n2->access())
         return false;
 
-    if (n1->type() == Node::Function && n2->type() == Node::Function) {
-        const FunctionNode* f1 = static_cast<const FunctionNode*>(n1);
-        const FunctionNode* f2 = static_cast<const FunctionNode*>(n2);
-
-        if (f1->isConst() < f2->isConst())
-            return true;
-        else if (f1->isConst() > f2->isConst())
-            return false;
-
-        if (f1->signature(false) < f2->signature(false))
-            return true;
-        else if (f1->signature(false) > f2->signature(false))
-            return false;
-    }
-
-    if (n1->isDocumentNode() && n2->isDocumentNode()) {
-        const DocumentNode* f1 = static_cast<const DocumentNode*>(n1);
-        const DocumentNode* f2 = static_cast<const DocumentNode*>(n2);
-        if (f1->fullTitle() < f2->fullTitle())
-            return true;
-        else if (f1->fullTitle() > f2->fullTitle())
-            return false;
-    }
-    else if (n1->isCollectionNode() && n2->isCollectionNode()) {
-        const CollectionNode* f1 = static_cast<const CollectionNode*>(n1);
-        const CollectionNode* f2 = static_cast<const CollectionNode*>(n2);
-        if (f1->fullTitle() < f2->fullTitle())
-            return true;
-        else if (f1->fullTitle() > f2->fullTitle())
-            return false;
-    }
-
     return false;
 }
 
@@ -379,6 +380,8 @@ QString Node::pageTypeString() const
 QString Node::pageTypeString(unsigned char t)
 {
     switch ((PageType)t) {
+    case Node::AttributionPage:
+        return "attribution";
     case Node::ApiPage:
         return "api";
     case Node::ArticlePage:
@@ -1266,8 +1269,17 @@ bool Aggregate::isSameSignature(const FunctionNode *f1, const FunctionNode *f2)
               ### hack for C++ to handle superfluous
               "Foo::" prefixes gracefully
             */
-            if (t1 != t2 && t1 != (f2->parent()->name() + "::" + t2))
-                return false;
+            if (t1 != t2 && t1 != (f2->parent()->name() + "::" + t2)) {
+                // Accept a difference in the template parametters of the type if one
+                // is omited (eg. "QAtomicInteger" == "QAtomicInteger<T>")
+                auto ltLoc = t1.indexOf('<');
+                auto gtLoc = t1.indexOf('>', ltLoc);
+                if (ltLoc < 0 || gtLoc < ltLoc)
+                    return false;
+                t1.remove(ltLoc, gtLoc - ltLoc + 1);
+                if (t1 != t2)
+                    return false;
+            }
         }
         ++p1;
         ++p2;
@@ -2030,6 +2042,7 @@ FunctionNode::FunctionNode(Aggregate *parent, const QString& name)
       isDeleted_(false),
       isDefaulted_(false),
       isFinal_(false),
+      isOverride_(false),
       reimplementedFrom_(0)
 {
     setGenus(Node::CPP);
@@ -2056,6 +2069,7 @@ FunctionNode::FunctionNode(NodeType type, Aggregate *parent, const QString& name
       isDeleted_(false),
       isDefaulted_(false),
       isFinal_(false),
+      isOverride_(false),
       reimplementedFrom_(0)
 {
     setGenus(Node::QML);
