@@ -69,7 +69,7 @@ namespace {
 }
 
 static void parseRect(const QString &value, QRect *rect) {
-    const QStringList l = value.split(QLatin1Char(' '));
+    const QVector<QStringRef> l = value.splitRef(QLatin1Char(' '));
     rect->setRect(l[0].toInt(), l[1].toInt(), l[2].toInt(), l[3].toInt());
 }
 
@@ -78,12 +78,6 @@ static QString msgImageNotLoaded(const QString &f)        {
 }
 
 // ------------ DeviceSkinButtonArea
-DeviceSkinButtonArea::DeviceSkinButtonArea() :
-    keyCode(0),
-    activeWhenClosed(0)
-{
-}
-
 QDebug &operator<<(QDebug &str, const DeviceSkinButtonArea &a)
 {
 
@@ -391,9 +385,9 @@ DeviceSkin::DeviceSkin(const DeviceSkinParameters &parameters,  QWidget *p ) :
     setAttribute(Qt::WA_NoSystemBackground);
 
     setZoom(1.0);
-    connect( t_skinkey, SIGNAL(timeout()), this, SLOT(skinKeyRepeat()) );
+    connect(t_skinkey, &QTimer::timeout, this, &DeviceSkin::skinKeyRepeat );
     t_parentmove->setSingleShot( true );
-    connect( t_parentmove, SIGNAL(timeout()), this, SLOT(moveParent()) );
+    connect(t_parentmove, &QTimer::timeout, this, &DeviceSkin::moveParent );
 }
 
 void DeviceSkin::skinKeyRepeat()
@@ -543,14 +537,14 @@ void DeviceSkin::paintEvent( QPaintEvent *)
     if ( buttonPressed == true ) {
         toDraw += buttonIndex;
     }
-    foreach (int toggle, m_parameters.toggleAreaList) {
+    for (int toggle : qAsConst(m_parameters.toggleAreaList)) {
         const DeviceSkinButtonArea &ba = m_parameters.buttonAreas[toggle];
         if (flipped_open || ba.activeWhenClosed) {
             if (ba.toggleArea && ba.toggleActiveArea)
                 toDraw += toggle;
         }
     }
-    foreach (int button, toDraw ) {
+    for (int button : qAsConst(toDraw)) {
         const DeviceSkinButtonArea &ba = m_parameters.buttonAreas[button];
         const QRect r = buttonRegions[button].boundingRect();
         if ( ba.area.count() > 2 )
