@@ -39,12 +39,12 @@ QString findQmlDirectory(int platform, const QString &startDirectoryName);
 
 struct QmlImportScanResult {
     struct Module {
-        QString relativeInstallPath() const;
         QString installPath(const QString &root) const;
 
         QString name;
         QString className;
         QString sourcePath;
+        QString relativePath;
     };
 
     QmlImportScanResult() : ok(false) {}
@@ -55,6 +55,8 @@ struct QmlImportScanResult {
     QStringList plugins;
 };
 
+bool operator==(const QmlImportScanResult::Module &m1, const QmlImportScanResult::Module &m2);
+
 QmlImportScanResult runQmlImportScanner(const QString &directory, const QString &qmlImportPath,
                                         bool usesWidgets, int platform, DebugMatchMode debugMatchMode,
                                         QString *errorMessage);
