@@ -1,34 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2017 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL3$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
 ** packaging of this file. Please review the following information to
 ** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -60,6 +63,9 @@ using namespace ABI::Windows::Management::Deployment;
 using namespace ABI::Windows::ApplicationModel;
 using namespace ABI::Windows::System;
 
+typedef IAsyncOperationWithProgressCompletedHandler<DeploymentResult *, DeploymentProgress> DeploymentResultHandler;
+typedef IAsyncOperationWithProgress<DeploymentResult *, DeploymentProgress> DeploymentOperation;
+
 QT_USE_NAMESPACE
 
 // Set a break handler for gracefully breaking long-running ops
@@ -343,8 +349,6 @@ AppxLocalEngine::AppxLocalEngine(Runner *runner)
 
 AppxLocalEngine::~AppxLocalEngine()
 {
-    Q_D(const AppxLocalEngine);
-    CloseHandle(d->processHandle);
 }
 
 bool AppxLocalEngine::installPackage(IAppxManifestReader *reader, const QString &filePath)
@@ -378,7 +382,7 @@ bool AppxLocalEngine::installPackage(IAppxManifestReader *reader, const QString
     hr = d->uriFactory->CreateUri(hStringFromQString(nativeFilePath), &uri);
     RETURN_FALSE_IF_FAILED("Failed to create an URI for the package");
 
-    ComPtr<IAsyncOperationWithProgress<DeploymentResult *, DeploymentProgress>> deploymentOperation;
+    ComPtr<DeploymentOperation> deploymentOperation;
     if (addInsteadOfRegister) {
         hr = d->packageManager->AddPackageAsync(uri.Get(), NULL, DeploymentOptions_None,
                                                 &deploymentOperation);
@@ -390,19 +394,40 @@ bool AppxLocalEngine::installPackage(IAppxManifestReader *reader, const QString
         RETURN_FALSE_IF_FAILED("Failed to start package registration");
     }
 
+    HANDLE ev = CreateEvent(NULL, FALSE, FALSE, NULL);
+    hr = deploymentOperation->put_Completed(Callback<DeploymentResultHandler>([ev](DeploymentOperation *, AsyncStatus) {
+                                        SetEvent(ev);
+                                        return S_OK;
+                                    }).Get());
+    RETURN_FALSE_IF_FAILED("Could not register deployment completed callback.");
+    DWORD ret = WaitForSingleObjectEx(ev, 15000, FALSE);
+    CloseHandle(ev);
+    if (ret != WAIT_OBJECT_0) {
+        if (ret == WAIT_TIMEOUT)
+            qCWarning(lcWinRtRunner) << "Deployment did not finish within 15 seconds.";
+        else
+            qCWarning(lcWinRtRunner) << "Deployment finished event was not triggered.";
+        return false;
+    }
+
     ComPtr<IDeploymentResult> results;
-    while ((hr = deploymentOperation->GetResults(&results)) == E_ILLEGAL_METHOD_CALL)
-        Sleep(1);
+    hr = deploymentOperation->GetResults(&results);
+    RETURN_FALSE_IF_FAILED("Failed to retrieve package registration results.");
 
     HRESULT errorCode;
     hr = results->get_ExtendedErrorCode(&errorCode);
-    RETURN_FALSE_IF_FAILED("Failed to retrieve package registration results.");
+    RETURN_FALSE_IF_FAILED("Failed to retrieve extended error code.");
 
     if (FAILED(errorCode)) {
-        HString errorText;
-        if (SUCCEEDED(results->get_ErrorText(errorText.GetAddressOf()))) {
-            qCWarning(lcWinRtRunner) << "Unable to register package:"
-                                     << QString::fromWCharArray(errorText.GetRawBuffer(NULL));
+        if (HRESULT_CODE(errorCode) == ERROR_INSTALL_PREREQUISITE_FAILED) {
+            qCWarning(lcWinRtRunner) << "Unable to register package: A requirement for installation was not met. "
+                "Check that your Windows version matches TargetDeviceFamily's MinVersion set in your AppxManifest.xml.";
+        } else {
+            HString errorText;
+            if (SUCCEEDED(results->get_ErrorText(errorText.GetAddressOf()))) {
+                qCWarning(lcWinRtRunner) << "Unable to register package:"
+                    << QString::fromWCharArray(errorText.GetRawBuffer(NULL));
+            }
         }
         if (HRESULT_CODE(errorCode) == ERROR_INSTALL_POLICY_FAILURE) {
             // The user's license has expired. Give them the opportunity to renew it.
@@ -462,17 +487,40 @@ bool AppxLocalEngine::remove()
     qCDebug(lcWinRtRunner) << __FUNCTION__;
 
     // ### TODO: use RemovePackageWithOptions to preserve previous state when re-installing
-    ComPtr<IAsyncOperationWithProgress<DeploymentResult *, DeploymentProgress>> deploymentOperation;
+    ComPtr<DeploymentOperation> deploymentOperation;
     HRESULT hr = d->packageManager->RemovePackageAsync(hStringFromQString(d->packageFullName), &deploymentOperation);
     RETURN_FALSE_IF_FAILED("Unable to start package removal");
 
-    ComPtr<IDeploymentResult> results;
-    while ((hr = deploymentOperation.Get()->GetResults(&results)) == E_ILLEGAL_METHOD_CALL)
-        Sleep(1);
+    HANDLE ev = CreateEvent(NULL, FALSE, FALSE, NULL);
+    hr = deploymentOperation->put_Completed(Callback<DeploymentResultHandler>([ev](DeploymentOperation *, AsyncStatus) {
+                                        SetEvent(ev);
+                                        return S_OK;
+                                    }).Get());
+    RETURN_FALSE_IF_FAILED("Could not register deployment completed callback.");
+    DWORD ret = WaitForSingleObjectEx(ev, 15000, FALSE);
+    CloseHandle(ev);
+    if (ret != WAIT_OBJECT_0) {
+        if (ret == WAIT_TIMEOUT)
+            qCWarning(lcWinRtRunner) << "Deployment did not finish within 15 seconds.";
+        else
+            qCWarning(lcWinRtRunner) << "Deployment finished event was not triggered.";
+        return false;
+    }
 
-    RETURN_FALSE_IF_FAILED("Unable to remove package");
+    ComPtr<IAsyncInfo> asyncInfo;
+    hr = deploymentOperation.As(&asyncInfo);
+    RETURN_FALSE_IF_FAILED("Failed to cast deployment operation.");
 
-    return SUCCEEDED(hr);
+    AsyncStatus status;
+    hr = asyncInfo->get_Status(&status);
+    RETURN_FALSE_IF_FAILED("Failed to retrieve deployment operation's status.");
+
+    if (status != Completed) {
+        qCWarning(lcWinRtRunner) << "Unable to remove package.";
+        return false;
+    }
+
+    return true;
 }
 
 bool AppxLocalEngine::start()
